@@ -221,10 +221,10 @@ double *polyhedron_volumes, double *polyhedron_areas, double *polyhedron_lengths
 double *polyhedron_aberrations, double *face_areas, double *face_lengths,
 double *face_aberrations, double *edge_lengths, double *edge_angles);
 
-static int static_build (GtkWidget *text, static_polytope *polytope);
+static void static_build (int *out, GtkWidget *text, static_polytope *polytope);
 
 static static_polytope *static_start (gamgi_dlist *atoms, gamgi_group *group,
-gamgi_atom *atom, gamgi_bool global, double radius, gamgi_bool copy);
+gamgi_atom *atom, gamgi_bool global, double radius, gamgi_enum structure);
 
 static void static_end (static_polytope *polytope);
 
@@ -234,7 +234,7 @@ static void static_end (static_polytope *polytope);
 
 gamgi_bool gamgi_chem_polytope (gamgi_dlist *atoms, gamgi_group *group,
 gamgi_atom *atom, gamgi_bool global, double radius, gamgi_bool copy,
-GtkWidget *text);
+int *out, GtkWidget *text);
 
 /*************
  * Rationale *
