@@ -220,19 +220,16 @@ gamgi_object object;
 void (*draw) (struct _gamgi_direction *);
 void (*projection) (double *, double *);
 
+gamgi_enum reference;
+gamgi_enum type;
+
 int uvw[3];
 gamgi_enum vectors;
 int node[4];
-gamgi_atom *atoms[2];
-
-gamgi_enum reference;
-gamgi_enum structure, filter;
-double thickness;
 
 double origin[3], center[3];
 double quaternion[4];
 
-gamgi_enum type;
 double *points;
 int *loops;
 int n_points, n_loops;
@@ -259,19 +256,16 @@ gamgi_object object;
 void (*draw) (struct _gamgi_plane *);
 void (*projection) (double *, double *);
 
+gamgi_enum reference;
+gamgi_enum type;
+
 int hkl[3];
 gamgi_enum vectors;
 int order;
-gamgi_atom *atoms[3];
-
-gamgi_enum reference;
-gamgi_enum structure, filter;
-double thickness;
 
 double origin[3], center[3];
 double quaternion[4];
 
-gamgi_enum type;
 double *points;
 int *loops;
 int n_points, n_loops;
