@@ -181,6 +181,7 @@ gamgi_dlist *dlist;
 gamgi_text *text_new;
 gamgi_orbital *orbital_new;
 gamgi_atom *atom_new;
+gamgi_direction *direction_new;
 gamgi_plane *plane_new;
 
 plane_new = gamgi_engine_create_plane ();
@@ -188,6 +189,12 @@ static_start (GAMGI_CAST_OBJECT plane_new);
 gamgi_engine_copy_out_plane (plane, plane_new);
 plane_new->object.number = gamgi_engine_number_plane_get ();
 
+dlist = plane->direction_start;
+while (dlist != NULL)
+  { direction_new = gamgi_engine_copy_direction (GAMGI_CAST_DIRECTION dlist->data);
+    gamgi_engine_link_direction_plane (direction_new, plane_new);
+    dlist = dlist->next; }
+
 dlist = plane->atom_start;
 while (dlist != NULL)
   { atom_new = gamgi_engine_copy_atom (GAMGI_CAST_ATOM dlist->data);
