@@ -148,6 +148,7 @@ int i;
 static_copy (GAMGI_CAST_OBJECT direction, GAMGI_CAST_OBJECT direction_new);
 direction_new->projection = direction->projection;
 direction_new->draw = direction->draw;
+direction_new->reference = direction->reference;
 direction_new->type = direction->type;
 
 /*****************************
@@ -164,14 +165,6 @@ direction_new->node[1] = direction->node[1];
 direction_new->node[2] = direction->node[2];
 direction_new->node[3] = direction->node[3];
 
-direction_new->reference = direction->reference;
-direction_new->structure = direction->structure;
-direction_new->filter = direction->filter;
-direction_new->thickness = direction->thickness;
-
-direction_new->atoms[0] = NULL;
-direction_new->atoms[1] = NULL;
-
 /**************************************
  * copy position and orientation data *
  **************************************/
@@ -226,6 +219,7 @@ int i;
 static_copy (GAMGI_CAST_OBJECT plane, GAMGI_CAST_OBJECT plane_new);
 plane_new->projection = plane->projection;
 plane_new->draw = plane->draw;
+plane_new->reference = plane->reference;
 plane_new->type = plane->type;
 
 /*****************************
@@ -236,18 +230,8 @@ plane_new->hkl[0] = plane->hkl[0];
 plane_new->hkl[1] = plane->hkl[1];
 plane_new->hkl[2] = plane->hkl[2];
 plane_new->vectors = plane->vectors;
-
 plane_new->order = plane->order;
 
-plane_new->reference = plane->reference;
-plane_new->structure = plane->structure;
-plane_new->filter = plane->filter;
-plane_new->thickness = plane->thickness;
-
-plane_new->atoms[0] = NULL;
-plane_new->atoms[1] = NULL;
-plane_new->atoms[2] = NULL;
-
 /**************************************
  * copy position and orientation data *
  **************************************/
