@@ -194,6 +194,8 @@ direction->object.number = gamgi_engine_number_direction_get ();
  * initialise direction *
  ************************/
 
+direction->reference = FALSE;
+
 direction->uvw[0] = 0;
 direction->uvw[1] = 0;
 direction->uvw[2] = 0;
@@ -204,14 +206,6 @@ direction->node[1] = 0;
 direction->node[2] = 0;
 direction->node[3] = 0;
 
-direction->atoms[0] = NULL;
-direction->atoms[1] = NULL;
-
-direction->reference = FALSE;
-direction->structure = FALSE;
-direction->filter = FALSE;
-direction->thickness = 0.0;
-
 direction->origin[0] = 0.0;
 direction->origin[1] = 0.0;
 direction->origin[2] = 0.0;
@@ -256,21 +250,14 @@ plane->object.number = gamgi_engine_number_plane_get ();
  * initialise plane *
  ********************/
 
+plane->reference = FALSE;
+
 plane->hkl[0] = 0;
 plane->hkl[1] = 0;
 plane->hkl[2] = 0;
 plane->vectors = FALSE;
 plane->order = 1;
 
-plane->atoms[0] = NULL;
-plane->atoms[1] = NULL;
-plane->atoms[2] = NULL;
-
-plane->reference = FALSE;
-plane->structure = FALSE;
-plane->filter = FALSE;
-plane->thickness = 0.0;
-
 plane->origin[0] = 0.0;
 plane->origin[1] = 0.0;
 plane->origin[2] = 0.0;
