@@ -1184,9 +1184,9 @@ vbox_dialog = gtk_vbox_new (FALSE, 5);
 gtk_container_add (GTK_CONTAINER (dialog), vbox_dialog);
 gtk_widget_show (vbox_dialog);
 
-/***************
- * Cell object *
- ***************/
+/*************
+ * Cell Name *
+ *************/
 
 hbox_center = gtk_hbox_new (TRUE, 5);
 gtk_box_pack_start (GTK_BOX (vbox_dialog), hbox_center, FALSE, FALSE, 0);
@@ -1196,7 +1196,7 @@ hbox_left = gtk_hbox_new (FALSE, 5);
 gtk_box_pack_start (GTK_BOX (hbox_center), hbox_left, FALSE, FALSE, 0);
 gtk_widget_show (hbox_left);
 
-label = gtk_label_new ("Cell");
+label = gtk_label_new ("Name");
 gtk_box_pack_start (GTK_BOX (hbox_left), label, FALSE, FALSE, 0);
 gtk_widget_show (label);
 
