@@ -564,10 +564,10 @@ if (gtk_tree_model_iter_has_child (model, &new) == TRUE)
 gtk_combo_box_get_active_iter (GTK_COMBO_BOX (combo), &new);
 gtk_tree_model_get (model, &new, 0, &name, -1);
 
-if (strcmp (name, "Pick") == 0)
+if (strcmp (name, "Pick") == 0 || strcmp (name, "Region") == 0)
   {
-  gamgi_gtk_select_method_pick ("widget_min", window);
-  gamgi_gtk_select_method_pick ("widget_max", window);
+  gamgi_gtk_select_method_direct ("widget_min", window);
+  gamgi_gtk_select_method_direct ("widget_max", window);
   }
 else if (strcmp (name, "System") == 0)
   {
@@ -1906,7 +1906,8 @@ gamgi_bool action, gamgi_window *window)
 {
 gamgi_cell *cell;
 gamgi_dlist *dlist, *dlist_new;
-gamgi_bool condition, borders;
+gamgi_enum borders;
+gamgi_bool condition;
 int min, max;
 
 /********************
@@ -2324,10 +2325,7 @@ else
  * to Current and the model is updated   *
  *****************************************/
 
-if (gamgi->cells == NULL)
-  gamgi_global_selection_hide ("button_cell");
-else
-  gamgi_global_selection_show ("button_cell");
+gamgi_global_selection_update_windows (&gamgi->cells, "button_cell");
 
 static_reset (window);
 }
