@@ -82,6 +82,71 @@ double translation[3], rotation[3];
 float red, green, blue;
 double scale; } cache;
 
+static void static_atom_remove (gamgi_direction *direction, gamgi_bool *link)
+{
+if (cache.structure != GAMGI_CHEM_STRUCTURE_LINK)
+  {
+  if (link[0] == TRUE)
+    { gamgi_engine_unlink_atom (cache.atom1); gamgi_engine_remove_atom (cache.atom1); }
+  if (link[1] == TRUE)
+    { gamgi_engine_unlink_atom (cache.atom2); gamgi_engine_remove_atom (cache.atom2); }
+  }
+}
+
+static gamgi_bool static_atom_parent (gamgi_direction *direction, gamgi_atom *atom)
+{
+if (gamgi_engine_find_atom_direction (atom->object.number, direction) != NULL)
+  {
+  gamgi_engine_unlink_atom (atom);
+  gamgi_engine_link_object_object (GAMGI_CAST_OBJECT atom, direction->object.object);
+  return TRUE;
+  }
+
+return FALSE;
+}
+
+static void static_direction_remove (gamgi_direction *direction, gamgi_bool *link)
+{
+gamgi_dlist *dlist;
+
+/***************************************************
+ * this code is just to svoid a compilaton warning *
+ ***************************************************/
+
+link[0] = link[1] = FALSE;
+
+/***********************************************************
+ * save reference atoms before removing direction contents *
+ ***********************************************************/
+
+if (direction->reference == GAMGI_ENGINE_ATOM)
+  {
+  link[0] = static_atom_parent (direction, cache.atom1);
+  link[1] = static_atom_parent (direction, cache.atom2);
+  }
+
+dlist = direction->atom_start;
+while (dlist != NULL)
+  { gamgi_engine_remove_atom (GAMGI_CAST_ATOM dlist->data);
+    dlist = gamgi_engine_dlist_remove_start (dlist); }
+direction->atom_start = NULL;
+direction->atom_end = NULL;
+
+dlist = direction->orbital_start;
+while (dlist != NULL)
+  { gamgi_engine_remove_orbital (GAMGI_CAST_ORBITAL dlist->data);
+    dlist = gamgi_engine_dlist_remove_start (dlist); }
+direction->orbital_start = NULL;
+direction->orbital_end = NULL;
+
+dlist = direction->text_start;
+while (dlist != NULL)
+  { gamgi_engine_remove_text (GAMGI_CAST_TEXT dlist->data);
+    dlist = gamgi_engine_dlist_remove_start (dlist); }
+direction->text_start = NULL;
+direction->text_end = NULL;
+}
+
 static GtkWidget *static_atom (GtkWidget *dialog)
 {
 GtkWidget *entry;
@@ -154,6 +219,7 @@ static void static_start_cell (gamgi_window *window)
 GtkWidget *dialog = window->dialog0;
 GtkWidget *entry;
 GtkWidget *combo;
+int row;
  
 entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_cell");
 gtk_entry_set_text (GTK_ENTRY (entry), "");
@@ -165,8 +231,18 @@ gtk_entry_set_text (GTK_ENTRY (entry), "");
 entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_w");
 gtk_entry_set_text (GTK_ENTRY (entry), "");
 
-combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_vectors");
-gtk_combo_box_set_active (GTK_COMBO_BOX (combo), STATIC_VECTORS_LOCAL);
+combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_reference");
+row = gtk_combo_box_get_active (GTK_COMBO_BOX (combo));
+if (row == STATIC_REFERENCE_CELL)
+  {
+  combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_vectors");
+  gtk_combo_box_set_active (GTK_COMBO_BOX (combo), GAMGI_PHYS_DIRECTION_VECTORS - 1);
+  }
+else
+  {
+  combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_vectors");
+  gtk_combo_box_set_active (GTK_COMBO_BOX (combo), STATIC_VECTORS_LOCAL);
+  }
 }
 
 static void static_start_atom (gamgi_window *window)
@@ -303,16 +379,28 @@ static void static_start_projection (gamgi_window *window)
 {
 GtkWidget *dialog = window->dialog0;
 GtkWidget *combo;
+int row;
 
 /******************************************************
  * default for projection and type combo boxes: Local *
  ******************************************************/
 
-combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_net");
-gtk_combo_box_set_active (GTK_COMBO_BOX (combo), STATIC_NET_LOCAL);
-
-combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_model");
-gtk_combo_box_set_active (GTK_COMBO_BOX (combo), STATIC_MODEL_LOCAL);
+combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_reference");
+row = gtk_combo_box_get_active (GTK_COMBO_BOX (combo));
+if (row == STATIC_REFERENCE_CELL)
+  {
+  combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_net");
+  gtk_combo_box_set_active (GTK_COMBO_BOX (combo), STATIC_NET_WULFF);
+  combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_model");
+  gtk_combo_box_set_active (GTK_COMBO_BOX (combo), STATIC_MODEL_POLE);
+  }
+else
+  {
+  combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_net");
+  gtk_combo_box_set_active (GTK_COMBO_BOX (combo), STATIC_NET_LOCAL);
+  combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_model");
+  gtk_combo_box_set_active (GTK_COMBO_BOX (combo), STATIC_MODEL_LOCAL);
+  }
 }
 
 static void static_nodes (gamgi_cell *cell, gamgi_window *window)
@@ -346,6 +434,79 @@ else vectors = GAMGI_PHYS_CONVENTIONAL;
 gamgi_gtk_cell_symmetry_nodes (lattice, vectors, dialog);
 }
 
+static void static_vectors (GtkWidget *widget, void *data)
+{
+gamgi_window *window = GAMGI_CAST_WINDOW data;
+gamgi_cell *cell;
+GtkWidget *dialog = window->dialog0;
+
+cell = GAMGI_CAST_CELL gamgi_gtk_object_name_number (dialog,
+"entry_cell", GAMGI_ENGINE_CELL, window);
+if (cell != NULL) static_nodes (cell, window);
+}
+
+static void static_page_show (gamgi_window *window)
+{
+GtkWidget *dialog = window->dialog0;
+GtkWidget *vbox_scope, *vbox_position, *vbox_projection;
+
+vbox_scope = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "vbox_scope");
+vbox_position = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "vbox_position");
+vbox_projection = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "vbox_projection");
+
+gtk_widget_show (vbox_scope);
+gtk_widget_show (vbox_position);
+gtk_widget_show (vbox_projection);
+
+static_start_scope (window);
+static_start_position (window);
+static_start_projection (window);
+}
+
+static void static_page_hide (gamgi_window *window)
+{
+GtkWidget *dialog = window->dialog0;
+GtkWidget *vbox_position;
+GtkWidget *combo;
+int row;
+
+vbox_position = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "vbox_position");
+combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_reference");
+row = gtk_combo_box_get_active (GTK_COMBO_BOX (combo));
+if (row != STATIC_REFERENCE_LOCAL) gtk_widget_hide (vbox_position);
+}
+
+static void static_page_handle (gamgi_window *window)
+{
+GtkWidget *dialog = window->dialog0;
+GtkWidget *vbox_cell, *vbox_atom, *vbox_projection;
+GtkWidget *combo;
+int row;
+
+static_page_show (window);
+
+vbox_projection = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "vbox_projection");
+vbox_cell = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "vbox_cell");
+vbox_atom = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "vbox_atom");
+
+combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_reference");
+row = gtk_combo_box_get_active (GTK_COMBO_BOX (combo));
+if (row == STATIC_REFERENCE_ATOMS)
+  {
+  gtk_widget_hide (vbox_cell);
+  gtk_widget_show (vbox_atom);
+  static_start_atom (window);
+
+  gtk_widget_hide (vbox_projection);
+  }
+else
+  {
+  gtk_widget_hide (vbox_atom);
+  gtk_widget_show (vbox_cell);
+  static_start_cell (window);
+  }
+}
+
 static void static_cell (GtkWidget *widget, void *data)
 {
 gamgi_window *window = GAMGI_CAST_WINDOW data;
@@ -357,6 +518,16 @@ vbox_scope = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "vbox_scope");
 vbox_position = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "vbox_position");
 vbox_projection = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "vbox_projection");
 
+/****************************
+ * start all possible pages *
+ ****************************/
+
+static_page_show (window);
+
+/*************************************
+ * hide pages not used for this cell *
+ *************************************/
+
 cell = GAMGI_CAST_CELL gamgi_gtk_object_name_number (dialog,
 "entry_cell", GAMGI_ENGINE_CELL, window);
 if (cell != NULL)
@@ -375,57 +546,12 @@ if (cell != NULL)
 
 }
 
-static void static_vectors (GtkWidget *widget, void *data)
-{
-gamgi_window *window = GAMGI_CAST_WINDOW data;
-gamgi_cell *cell;
-GtkWidget *dialog = window->dialog0;
-
-cell = GAMGI_CAST_CELL gamgi_gtk_object_name_number (dialog,
-"entry_cell", GAMGI_ENGINE_CELL, window);
-if (cell != NULL) static_nodes (cell, window);
-}
-
 static void static_reference (GtkWidget *widget, void *data)
 {
 gamgi_window *window = GAMGI_CAST_WINDOW data;
-GtkWidget *dialog = window->dialog0;
-GtkWidget *vbox_cell, *vbox_atom;
-GtkWidget *vbox_scope, *vbox_position, *vbox_projection;
-GtkWidget *combo;
-int row;
-
-vbox_cell = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "vbox_cell");
-vbox_atom = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "vbox_atom");
-
-vbox_scope = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "vbox_scope");
-vbox_position = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "vbox_position");
-vbox_projection = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "vbox_projection");
-
-combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_reference");
-row = gtk_combo_box_get_active (GTK_COMBO_BOX (combo));
-
-gtk_widget_show (vbox_scope);
-static_start_scope (window);
-gtk_widget_show (vbox_position);
-static_start_position (window);
-
-if (row == STATIC_REFERENCE_ATOMS)
-  {
-  gtk_widget_hide (vbox_cell);
-  gtk_widget_show (vbox_atom);
-  static_start_atom (window);
-  gtk_widget_hide (vbox_projection);
-  }
-else
-  {
-  gtk_widget_hide (vbox_atom);
-  gtk_widget_show (vbox_cell);
-  static_start_cell (window);
-  gtk_widget_show (vbox_projection);
-  static_start_projection (window);
-  }
 
+static_page_handle (window);
+static_page_hide (window);
 }
 
 static void static_reset (gamgi_window *window)
@@ -542,7 +668,8 @@ row = gtk_combo_box_get_active (GTK_COMBO_BOX (combo));
 if (row < STATIC_REFERENCE_LOCAL)
   {
   cache.new[STATIC_REFERENCE] = TRUE;
-  cache.reference = row;
+  if (row == STATIC_REFERENCE_CELL) cache.reference = GAMGI_ENGINE_CELL;
+  if (row == STATIC_REFERENCE_ATOMS) cache.reference = GAMGI_ENGINE_ATOM;
   }
 
 /******************************************************************
@@ -684,7 +811,7 @@ row = gtk_combo_box_get_active (GTK_COMBO_BOX (combo));
 if (visible == TRUE)
   {
   cache.new[STATIC_STRUCTURE] = TRUE;
-  cache.structure = row;
+  cache.structure = 1 + row;
   }
 
 cache.new[STATIC_FILTER] = TRUE;
@@ -693,7 +820,7 @@ row = gtk_combo_box_get_active (GTK_COMBO_BOX (combo));
 if (visible == TRUE)
   {
   cache.new[STATIC_FILTER] = TRUE;
-  cache.filter = row;
+  cache.filter = 1 + row;
   }
 
 cache.new[STATIC_THICKNESS] = FALSE;
@@ -957,15 +1084,18 @@ return TRUE;
 static gamgi_bool static_apply (gamgi_direction *direction, gamgi_window *window)
 {
 gamgi_cell *cell;
+gamgi_object *parent;
+gamgi_dlist *dlist;
 char name[GAMGI_ENGINE_TOKEN];
 gamgi_projection projection;
 gamgi_enum reference, vectors, type;
-gamgi_enum structure, filter;
+gamgi_bool link[2];
 gamgi_bool new;
 double zero[3], euler[3], origin[3];
-double thickness, scale;
+double scale;
 float red, green, blue;
 int uvw[3], node[4];
+int pole, trace;
 
 /******************************
  * import data from direction *
@@ -1012,10 +1142,6 @@ if (cache.new[STATIC_V] == TRUE) uvw[1] = cache.uvw[1];
 if (cache.new[STATIC_W] == TRUE) uvw[2] = cache.uvw[2];
 if (cache.new[STATIC_VECTORS] == TRUE) vectors = cache.vectors;
 
-if (cache.new[STATIC_STRUCTURE] == TRUE) structure = cache.structure;
-if (cache.new[STATIC_FILTER] == TRUE) filter = cache.filter;
-if (cache.new[STATIC_THICKNESS] == TRUE) thickness = cache.thickness;
-
 if (cache.new[STATIC_NET] == TRUE) projection = cache.projection;
 if (cache.new[STATIC_MODEL] == TRUE) type = cache.type;
 if (cache.new[STATIC_O1] == TRUE) node[0] = cache.node[0];
@@ -1042,17 +1168,22 @@ if (cache.new[STATIC_SCALE] == TRUE) scale = cache.scale;
 
 if (cache.new[STATIC_REFERENCE] == TRUE)
   {
-  if (cache.reference == STATIC_ATOMS)
+  if (cache.reference == GAMGI_ENGINE_ATOM)
     {
     cell = NULL;
     uvw[0] = 0; uvw[1] = 0; uvw[2] = 0;
     vectors = GAMGI_PHYS_DIRECTION_VECTORS;
+    node[0] = 0; node[1] = 0; node[2] = 0; node[3] = 0;
     type = GAMGI_PHYS_LINE;
     projection = NULL;
-    node[0] = 0;
-    node[1] = 0;
-    node[2] = 0;
-    node[3] = 0;
+    }
+
+  if (reference == GAMGI_ENGINE_CELL)
+    {
+    if (cell->type == GAMGI_PHYS_PROJECTION)
+      { node[0] = 0; node[1] = 0; node[2] = 0; node[3] = 0; }
+    else
+      { type = GAMGI_PHYS_LINE; projection = NULL; }
     }
   }
 
@@ -1187,12 +1318,12 @@ if (direction->uvw[1] != uvw[1]) new = TRUE;
 if (direction->uvw[2] != uvw[2]) new = TRUE;
 if (direction->vectors != vectors) new = TRUE;
 
-if (direction->projection != projection) new = TRUE;
-if (direction->type != type) new = TRUE;
 if (direction->node[0] != node[0]) new = TRUE;
 if (direction->node[1] != node[1]) new = TRUE;
 if (direction->node[2] != node[2]) new = TRUE;
 if (direction->node[3] != node[3]) new = TRUE;
+if (direction->projection != projection) new = TRUE;
+if (direction->type != type) new = TRUE;
 
 if (new == TRUE && type == GAMGI_PHYS_LINE &&
 cache.new[STATIC_THICKNESS] == FALSE)
@@ -1215,14 +1346,6 @@ if (cache.local == TRUE)
  * build new direction *
  ***********************/
 
-/*******************
- * reset direction *
- *******************/
-
-gamgi_math_vector_zero (zero);
-gamgi_math_position_direction_rotation_set (direction, zero);
-gamgi_math_position_direction_translation_set (direction, zero);
-
 strcpy (direction->object.name, name);
 direction->reference = reference;
 direction->uvw[0] = uvw[0];
@@ -1230,32 +1353,103 @@ direction->uvw[1] = uvw[1];
 direction->uvw[2] = uvw[2];
 direction->vectors = vectors;
 
-direction->projection = projection;
-direction->type = type;
 direction->node[0] = node[0];
 direction->node[1] = node[1];
 direction->node[2] = node[2];
 direction->node[3] = node[3];
+direction->projection = projection;
+direction->type = type;
 
 direction->red = red;
 direction->green = green;
 direction->blue = blue;
 direction->object.scale = scale;
 
-/*
 if (new == TRUE)
   {
+  /****************************************************************
+   * rebuild arrays: unlink direction AFTER removing contents, as *
+   * reference atoms might need to be saved in the parent above   *
+   ****************************************************************/
+
+  static_direction_remove (direction, link);
+  gamgi_engine_unlink_direction (direction);
   free (direction->points);
-  free (direction->loops);
   direction->points = NULL;
+  free (direction->loops);
   direction->loops = NULL;
   direction->n_points = 0;
   direction->n_loops = 0;
-  }
-*/
 
-gamgi_math_position_direction_rotation_set (direction, euler);
-gamgi_math_position_direction_translation_set (direction, origin);
+  if (direction->reference == GAMGI_ENGINE_CELL)
+    {
+    /****************************************
+     * this is a crystallographic direction *
+     ****************************************/
+
+    if (cell->type == GAMGI_PHYS_PROJECTION)
+      {
+      if (direction->type == GAMGI_PHYS_POLE) pole = TRUE; else pole = FALSE;
+      if (direction->type == GAMGI_PHYS_TRACE) trace = TRUE; else trace = FALSE;
+      gamgi_phys_direction_projection (direction, cell, pole, trace);
+      }
+    else
+      {
+      dlist = gamgi_engine_dlist_atom_object (GAMGI_CAST_OBJECT cell, NULL);
+      dlist = gamgi_engine_filter_atom (dlist, 0, cache.filter,
+      GAMGI_ENGINE_DIRECTION, GAMGI_CAST_OBJECT cell);
+
+      gamgi_phys_direction_node (direction, cell,
+      cache.structure, cache.filter, cache.thickness, dlist);
+
+      while (dlist != NULL)
+        dlist = gamgi_engine_dlist_remove_start (dlist);
+      }
+    gamgi_engine_remove_direction (direction);
+    }
+
+  if (direction->reference == GAMGI_ENGINE_ATOM)
+    {
+    /*************************************************************
+     * this is an atomic direction: 1) get list of parent atoms  *
+     * 2) reorder list so the two defining atoms come first      *
+     *                                                           *
+     * the direction type is needed because of the rotation next *
+     *************************************************************/
+
+    direction->type = GAMGI_PHYS_LINE;
+    direction->vectors = GAMGI_PHYS_DIRECTION_VECTORS;
+
+    parent = gamgi_phys_direction_parent (cache.atom1, cache.atom2, window);
+    dlist = gamgi_engine_dlist_atom_object (parent, NULL);
+    dlist = gamgi_phys_direction_reorder (dlist, cache.atom1, cache.atom2);
+    dlist = gamgi_engine_filter_atom (dlist, 2, cache.filter, GAMGI_ENGINE_DIRECTION, parent);
+    if (parent->class <= GAMGI_ENGINE_DIRECTION) parent = GAMGI_CAST_OBJECT window->layer;
+
+    /**********************************************************
+     * reset and build direction line AFTER linking to parent *
+     **********************************************************/
+
+    gamgi_engine_link_object_object (GAMGI_CAST_OBJECT direction, parent);
+
+    gamgi_math_vector_zero (zero);
+    gamgi_math_position_direction_rotation_set (direction, zero);
+    gamgi_math_position_direction_translation_set (direction, zero);
+
+    gamgi_phys_direction_atoms (direction, cache.atom1,
+    cache.atom2, dlist, cache.structure, cache.thickness, TRUE);
+    static_atom_remove (direction, link);
+    }
+  }
+else
+  {
+  gamgi_math_vector_zero (zero);
+  gamgi_math_position_direction_rotation_set (direction, zero);
+  gamgi_math_position_direction_translation_set (direction, zero);
+
+  gamgi_math_position_direction_rotation_set (direction, euler);
+  gamgi_math_position_direction_translation_set (direction, origin);
+  }
 
 return TRUE;
 }
@@ -1453,7 +1647,7 @@ if (class == GAMGI_ENGINE_DIRECTION)
      ****************************************/
 
     gtk_combo_box_set_active (GTK_COMBO_BOX (combo), STATIC_REFERENCE_CELL);
-    static_reference (NULL, window);
+    static_page_handle (window);
 
     /***************************
      * set Cell identification *
@@ -1530,7 +1724,7 @@ if (class == GAMGI_ENGINE_DIRECTION)
      *******************************/
 
     gtk_combo_box_set_active (GTK_COMBO_BOX (combo), STATIC_REFERENCE_ATOMS);
-    static_reference (NULL, window);
+    static_page_handle (window);
     }
 
   /***************************************
@@ -1596,18 +1790,17 @@ if (class == GAMGI_ENGINE_DIRECTION)
   gtk_entry_set_text (GTK_ENTRY (entry), string);
 
   entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_scale");
-  if (gtk_widget_is_sensitive (entry) == TRUE)
-    {
-    sprintf (string, "%.*f", GAMGI_MATH_DECIMAL_SCALE, direction->object.scale);
-    gtk_entry_set_text (GTK_ENTRY (entry), string);
-    }
+  sprintf (string, "%.*f", GAMGI_MATH_DECIMAL_SCALE, direction->object.scale);
+  gtk_entry_set_text (GTK_ENTRY (entry), string);
   }
+
 else if (class == GAMGI_ENGINE_CELL)
   {
-  static_reference (NULL, window);
   entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_cell");
   sprintf (string, "%s %d", object->name, object->number);
   gtk_entry_set_text (GTK_ENTRY (entry), string);
+
+  static_page_hide (window);
   }
 else if (class == GAMGI_ENGINE_ATOM)
   {
@@ -1620,6 +1813,8 @@ else if (class == GAMGI_ENGINE_ATOM)
     { static_end_atom (dialog); entry = static_atom (dialog); }
   sprintf (string, "%s %d", object->name, object->number);
   gtk_entry_set_text (GTK_ENTRY (entry), string);
+
+  static_page_hide (window);
   }
 
 }
@@ -2119,7 +2314,7 @@ store = gtk_list_store_new (1, G_TYPE_STRING);
 gtk_list_store_append (store, &iter);
 gtk_list_store_set (store, &iter, 0, "Class", -1);
 gtk_list_store_append (store, &iter);
-gtk_list_store_set (store, &iter, 0, "Child", -1);
+gtk_list_store_set (store, &iter, 0, "Parent", -1);
 gtk_list_store_append (store, &iter);
 gtk_list_store_set (store, &iter, 0, "Identical", -1);
 gtk_list_store_append (store, &iter);
