@@ -555,7 +555,7 @@ gamgi_gtk_history_update (window->layer, window->layer->undo, GAMGI_ENGINE_UNDO)
  *******************************/
 
 dlist = gamgi_engine_dlist_atom_object (window->focus, NULL);
-dlist = gamgi_engine_filter_atom (dlist, group->filter,
+dlist = gamgi_engine_filter_atom (dlist, 0, group->filter,
 GAMGI_ENGINE_GROUP, window->focus);
 
 /***********************************
