@@ -23,8 +23,9 @@
 #include "gamgi_gtk_dialog.h"
 #include "gamgi_gtk_history.h"
 #include "gamgi_gtk_object.h"
-#include "gamgi_mesa_translate.h"
 #include "gamgi_mesa_select.h"
+#include "gamgi_mesa_translate.h"
+#include "gamgi_mesa_draw.h"
 #include "gamgi_math_vector.h"
 #include "gamgi_io_token.h"
 #include "gamgi_io_error.h"
@@ -368,7 +369,7 @@ if (window_mouse == NULL)
    * For all windows: redraw gl_area image *
    ****************************************/
 
-  gamgi_global_selection_draw ();
+  gamgi_mesa_draw_gamgi ();
   }
 else
   {
@@ -479,8 +480,7 @@ else
 static void static_init (gamgi_window *window)
 {
 static_reset (window);
-static_default_layer (window);
-static_default_window (window);
+static_list (NULL, window);
 }
 
 static void static_press (gamgi_object *object, void *data)
@@ -518,6 +518,7 @@ GtkWidget *dialog = window_dialog->dialog0;
 GtkWidget *combo;
 GtkWidget *button;
 GtkWidget *entry;
+gamgi_bool global;
 const char *name;
 int row;
 
@@ -537,17 +538,24 @@ button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_list");
 entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_layer");
 name = gtk_entry_get_text (GTK_ENTRY (entry));
 
+/************************************************************
+ * global selection can be used to select the second object *
+ * or the list of objects, not the first (main) object      *
+ ************************************************************/
+
+global = TRUE;
 if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == FALSE &&
-gamgi_io_token_check (name) == FALSE &&
-window_dialog != window_mouse) return;
+gamgi_io_token_check (name) == FALSE) global = FALSE;
 
 /************************************************************************
  * window_dialog is the (local) window where the dialog window was open *
  * window_mouse is the (global) window where the user presses the mouse *
  ************************************************************************/
 
+if (global == FALSE && window_dialog != window_mouse) return;
+
 gamgi_mesa_select_object (window_mouse, x, y,
-static_class (window_dialog), TRUE, static_press);
+static_class (window_dialog), global, static_press);
 }
 
 /*************** external function *************
