@@ -25,6 +25,7 @@
 #include "gamgi_gtk_object.h"
 #include "gamgi_mesa_select.h"
 #include "gamgi_mesa_translate.h"
+#include "gamgi_mesa_draw.h"
 #include "gamgi_math_vector.h"
 #include "gamgi_chem_bond.h"
 #include "gamgi_io_token.h"
@@ -277,23 +278,6 @@ gamgi_plane *plane_new = NULL;
 double translate[3];
 int i;
 
-/*******************************************************************
- * some objects, such as planes and directions, might depend       *
- * entirely on their parents (crystallographic planes,directions), *
- * or have a life of their own (atomic planes,directions). Only    *
- * the second can be linked to other parents (not necessarily in   *
- * the same layer). Dependent objects can be linked, however,      *
- * to all possible child objects, without any restrictions.        *
- *******************************************************************/
-
-if (gamgi_gtk_object_independence (GAMGI_CAST_OBJECT plane) == FALSE)
-  {
-  if (cache.local == TRUE)
-    gamgi_gtk_dialog_message_create ("Error",
-    "Plane is not independent", window);
-  return FALSE;
-  }
-
 /*******************
  * find host layer *
  *******************/
@@ -382,7 +366,7 @@ if (layer == NULL)
    * For all windows: redraw gl_area image *
    ****************************************/
 
-  gamgi_global_selection_draw ();
+  gamgi_mesa_draw_gamgi ();
   }
 else
   {
@@ -533,6 +517,7 @@ GtkWidget *dialog = window_dialog->dialog0;
 GtkWidget *combo;
 GtkWidget *button;
 GtkWidget *entry;
+gamgi_bool global;
 const char *name;
 int row;
 
@@ -552,17 +537,24 @@ button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_list");
 entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_plane");
 name = gtk_entry_get_text (GTK_ENTRY (entry));
 
+/************************************************************
+ * global selection can be used to select the second object *
+ * or the list of objects, not the first (main) object      *
+ ************************************************************/
+
+global = TRUE;
 if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == FALSE &&
-gamgi_io_token_check (name) == FALSE &&
-window_dialog != window_mouse) return;
+gamgi_io_token_check (name) == FALSE) global = FALSE;
 
 /************************************************************************
  * window_dialog is the (local) window where the dialog window was open *
  * window_mouse is the (global) window where the user presses the mouse *
  ************************************************************************/
 
+if (global == FALSE && window_dialog != window_mouse) return;
+
 gamgi_mesa_select_object (window_mouse, x, y,
-static_class (window_dialog), TRUE, static_press);
+static_class (window_dialog), global, static_press);
 }
 
 /*************** external function *************
