@@ -83,6 +83,85 @@ double translation[3], rotation[3];
 float red, green, blue;
 double scale; } cache;
 
+static void static_atom_remove (gamgi_plane *plane, gamgi_bool *link)
+{
+if (cache.structure != GAMGI_CHEM_STRUCTURE_LINK)
+  {
+  if (link[0] == TRUE)
+    { gamgi_engine_unlink_atom (cache.atom1); gamgi_engine_remove_atom (cache.atom1); }
+  if (link[1] == TRUE)
+    { gamgi_engine_unlink_atom (cache.atom2); gamgi_engine_remove_atom (cache.atom2); }
+  if (link[2] == TRUE)
+    { gamgi_engine_unlink_atom (cache.atom3); gamgi_engine_remove_atom (cache.atom3); }
+  }
+}
+
+static gamgi_bool static_atom_parent (gamgi_plane *plane, gamgi_atom *atom)
+{
+if (gamgi_engine_find_atom_plane (atom->object.number, plane) != NULL)
+  {
+  gamgi_engine_unlink_atom (atom);
+  gamgi_engine_link_object_object (GAMGI_CAST_OBJECT atom, plane->object.object);
+  return TRUE;
+  }
+
+return FALSE;
+}
+
+static void static_plane_remove (gamgi_plane *plane, gamgi_bool *link)
+{
+gamgi_dlist *dlist;
+
+/***************************************************
+ * this code is just to svoid a compilaton warning *
+ ***************************************************/
+
+link[0] = link[1] = link[2] = FALSE;
+
+/*******************************************************
+ * save reference atoms before removing plane contents *
+ *******************************************************/
+
+if (plane->reference == GAMGI_ENGINE_ATOM)
+  {
+  link[0] = static_atom_parent (plane, cache.atom1);
+  link[1] = static_atom_parent (plane, cache.atom2);
+  link[2] = static_atom_parent (plane, cache.atom3);
+  }
+
+/*************************
+ * remove plane contents *
+ *************************/
+
+dlist = plane->direction_start;
+while (dlist != NULL)
+  { gamgi_engine_remove_direction (GAMGI_CAST_DIRECTION dlist->data);
+    dlist = gamgi_engine_dlist_remove_start (dlist); }
+plane->direction_start = NULL;
+plane->direction_end = NULL;
+
+dlist = plane->atom_start;
+while (dlist != NULL)
+  { gamgi_engine_remove_atom (GAMGI_CAST_ATOM dlist->data);
+    dlist = gamgi_engine_dlist_remove_start (dlist); }
+plane->atom_start = NULL;
+plane->atom_end = NULL;
+
+dlist = plane->orbital_start;
+while (dlist != NULL)
+  { gamgi_engine_remove_orbital (GAMGI_CAST_ORBITAL dlist->data);
+    dlist = gamgi_engine_dlist_remove_start (dlist); }
+plane->orbital_start = NULL;
+plane->orbital_end = NULL;
+
+dlist = plane->text_start;
+while (dlist != NULL)
+  { gamgi_engine_remove_text (GAMGI_CAST_TEXT dlist->data);
+    dlist = gamgi_engine_dlist_remove_start (dlist); }
+plane->text_start = NULL;
+plane->text_end = NULL;
+}
+
 static GtkWidget *static_atom (GtkWidget *dialog)
 {
 GtkWidget *entry;
@@ -165,6 +244,7 @@ static void static_start_cell (gamgi_window *window)
 GtkWidget *dialog = window->dialog0;
 GtkWidget *entry;
 GtkWidget *combo;
+int row;
 
 entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_cell");
 gtk_entry_set_text (GTK_ENTRY (entry), "");
@@ -176,8 +256,19 @@ gtk_entry_set_text (GTK_ENTRY (entry), "");
 entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_l");
 gtk_entry_set_text (GTK_ENTRY (entry), "");
 
-combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_vectors");
-gtk_combo_box_set_active (GTK_COMBO_BOX (combo), STATIC_VECTORS_LOCAL);
+combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_reference");
+row = gtk_combo_box_get_active (GTK_COMBO_BOX (combo));
+if (row == STATIC_REFERENCE_CELL)
+  {
+  combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_vectors");
+  gtk_combo_box_set_active (GTK_COMBO_BOX (combo), GAMGI_PHYS_PLANE_VECTORS - 1);
+  }
+else
+  {
+  combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_vectors");
+  gtk_combo_box_set_active (GTK_COMBO_BOX (combo), STATIC_VECTORS_LOCAL);
+  }
+
 }
 
 static void static_start_atom (gamgi_window *window)
@@ -327,16 +418,28 @@ static void static_start_projection (gamgi_window *window)
 {
 GtkWidget *dialog = window->dialog0;
 GtkWidget *combo;
+int row;
 
 /******************************************************
  * default for projection and type combo boxes: Local *
  ******************************************************/
 
-combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_net");
-gtk_combo_box_set_active (GTK_COMBO_BOX (combo), STATIC_NET_LOCAL);
-
-combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_model");
-gtk_combo_box_set_active (GTK_COMBO_BOX (combo), STATIC_MODEL_LOCAL);
+combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_reference");
+row = gtk_combo_box_get_active (GTK_COMBO_BOX (combo));
+if (row == STATIC_REFERENCE_CELL)
+  {
+  combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_net");
+  gtk_combo_box_set_active (GTK_COMBO_BOX (combo), STATIC_NET_WULFF);
+  combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_model");
+  gtk_combo_box_set_active (GTK_COMBO_BOX (combo), STATIC_MODEL_POLE);
+  }
+else
+  {
+  combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_net");
+  gtk_combo_box_set_active (GTK_COMBO_BOX (combo), STATIC_NET_LOCAL);
+  combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_model");
+  gtk_combo_box_set_active (GTK_COMBO_BOX (combo), STATIC_MODEL_LOCAL);
+  }
 }
 
 static void static_nodes (gamgi_cell *cell, gamgi_window *window)
@@ -378,6 +481,79 @@ else vectors = GAMGI_PHYS_CONVENTIONAL;
 gamgi_gtk_cell_symmetry_nodes (lattice, vectors, dialog);
 }
 
+static void static_vectors (GtkWidget *widget, void *data)
+{
+gamgi_window *window = GAMGI_CAST_WINDOW data;
+gamgi_cell *cell;
+GtkWidget *dialog = window->dialog0;
+
+cell = GAMGI_CAST_CELL gamgi_gtk_object_name_number (dialog,
+"entry_cell", GAMGI_ENGINE_CELL, window);
+if (cell != NULL) static_nodes (cell, window);
+}
+
+static void static_page_show (gamgi_window *window)
+{
+GtkWidget *dialog = window->dialog0;
+GtkWidget *vbox_scope, *vbox_position, *vbox_projection;
+
+vbox_scope = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "vbox_scope");
+vbox_position = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "vbox_position");
+vbox_projection = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "vbox_projection");
+
+gtk_widget_show (vbox_scope);
+gtk_widget_show (vbox_position);
+gtk_widget_show (vbox_projection);
+
+static_start_scope (window);
+static_start_position (window);
+static_start_projection (window);
+}
+
+static void static_page_hide (gamgi_window *window)
+{
+GtkWidget *dialog = window->dialog0;
+GtkWidget *vbox_position;
+GtkWidget *combo;
+int row;
+
+vbox_position = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "vbox_position");
+combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_reference");
+row = gtk_combo_box_get_active (GTK_COMBO_BOX (combo));
+if (row != STATIC_REFERENCE_LOCAL) gtk_widget_hide (vbox_position);
+}
+
+static void static_page_handle (gamgi_window *window)
+{
+GtkWidget *dialog = window->dialog0;
+GtkWidget *vbox_cell, *vbox_atom, *vbox_projection;
+GtkWidget *combo;
+int row;
+
+static_page_show (window);
+
+vbox_projection = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "vbox_projection");
+vbox_cell = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "vbox_cell");
+vbox_atom = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "vbox_atom");
+
+combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_reference");
+row = gtk_combo_box_get_active (GTK_COMBO_BOX (combo));
+if (row == STATIC_REFERENCE_ATOMS)
+  {
+  gtk_widget_hide (vbox_cell);
+  gtk_widget_show (vbox_atom);
+  static_start_atom (window);
+
+  gtk_widget_hide (vbox_projection);
+  }
+else
+  {
+  gtk_widget_hide (vbox_atom);
+  gtk_widget_show (vbox_cell);
+  static_start_cell (window);
+  }
+}
+
 static void static_cell (GtkWidget *widget, void *data)
 {
 gamgi_window *window = GAMGI_CAST_WINDOW data;
@@ -389,6 +565,16 @@ vbox_scope = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "vbox_scope");
 vbox_position = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "vbox_position");
 vbox_projection = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "vbox_projection");
 
+/****************************
+ * start all possible pages *
+ ****************************/
+
+static_page_show (window);
+
+/*************************************
+ * hide pages not used for this cell *
+ *************************************/
+
 cell = GAMGI_CAST_CELL gamgi_gtk_object_name_number (dialog,
 "entry_cell", GAMGI_ENGINE_CELL, window);
 if (cell != NULL)
@@ -413,57 +599,12 @@ if (cell != NULL)
 
 }
 
-static void static_vectors (GtkWidget *widget, void *data)
-{
-gamgi_window *window = GAMGI_CAST_WINDOW data;
-gamgi_cell *cell;
-GtkWidget *dialog = window->dialog0;
-
-cell = GAMGI_CAST_CELL gamgi_gtk_object_name_number (dialog,
-"entry_cell", GAMGI_ENGINE_CELL, window);
-if (cell != NULL) static_nodes (cell, window);
-}
-
 static void static_reference (GtkWidget *widget, void *data)
 {
 gamgi_window *window = GAMGI_CAST_WINDOW data;
-GtkWidget *dialog = window->dialog0;
-GtkWidget *vbox_cell, *vbox_atom;
-GtkWidget *vbox_scope, *vbox_position, *vbox_projection;
-GtkWidget *combo;
-int row;
-
-vbox_cell = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "vbox_cell");
-vbox_atom = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "vbox_atom");
-
-vbox_scope = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "vbox_scope");
-vbox_position = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "vbox_position");
-vbox_projection = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "vbox_projection");
-
-combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_reference");
-row = gtk_combo_box_get_active (GTK_COMBO_BOX (combo));
-
-gtk_widget_show (vbox_scope);
-static_start_scope (window);
-gtk_widget_show (vbox_position);
-static_start_position (window);
-
-if (row == STATIC_REFERENCE_ATOMS)
-  {
-  gtk_widget_hide (vbox_cell);
-  gtk_widget_show (vbox_atom);
-  static_start_atom (window);
-  gtk_widget_hide (vbox_projection);
-  }
-else
-  {
-  gtk_widget_hide (vbox_atom);
-  gtk_widget_show (vbox_cell);
-  static_start_cell (window);
-  gtk_widget_show (vbox_projection);
-  static_start_projection (window);
-  }
 
+static_page_handle (window);
+static_page_hide (window);
 }
 
 static void static_reset (gamgi_window *window)
@@ -579,7 +720,8 @@ row = gtk_combo_box_get_active (GTK_COMBO_BOX (combo));
 if (row < STATIC_REFERENCE_LOCAL)
   {
   cache.new[STATIC_REFERENCE] = TRUE;
-  cache.reference = row;
+  if (row == STATIC_REFERENCE_CELL) cache.reference = GAMGI_ENGINE_CELL;
+  if (row == STATIC_REFERENCE_ATOMS) cache.reference = GAMGI_ENGINE_ATOM;
   }
 
 /*********************************************************************
@@ -729,7 +871,7 @@ row = gtk_combo_box_get_active (GTK_COMBO_BOX (combo));
 if (visible == TRUE)
   {
   cache.new[STATIC_STRUCTURE] = TRUE;
-  cache.structure = row;
+  cache.structure = 1 + row;
   }
 
 cache.new[STATIC_FILTER] = FALSE;
@@ -738,7 +880,7 @@ row = gtk_combo_box_get_active (GTK_COMBO_BOX (combo));
 if (visible == TRUE)
   {
   cache.new[STATIC_FILTER] = TRUE;
-  cache.filter = row;
+  cache.filter = 1 + row;
   }
 
 cache.new[STATIC_THICKNESS] = FALSE;
@@ -1015,16 +1157,19 @@ return TRUE;
 static gamgi_bool static_apply (gamgi_plane *plane, gamgi_window *window)
 {
 gamgi_cell *cell;
+gamgi_object *parent;
+gamgi_dlist *dlist;
 char name[GAMGI_ENGINE_TOKEN];
 gamgi_projection projection;
 gamgi_enum reference, vectors, type;
-gamgi_enum structure, filter;
+gamgi_bool link[3];
 gamgi_bool new;
 double zero[3], euler[3], origin[3];
-double thickness, scale;
+double scale;
 float red, green, blue;
 int hkl[3];
 int order, o1, o2, o3;
+int pole, trace;
 
 /**************************
  * import data from plane *
@@ -1068,10 +1213,6 @@ if (cache.new[STATIC_K] == TRUE) hkl[1] = cache.hkl[1];
 if (cache.new[STATIC_L] == TRUE) hkl[2] = cache.hkl[2];
 if (cache.new[STATIC_VECTORS] == TRUE) vectors = cache.vectors;
 
-if (cache.new[STATIC_STRUCTURE] == TRUE) structure = cache.structure;
-if (cache.new[STATIC_FILTER] == TRUE) filter = cache.filter;
-if (cache.new[STATIC_THICKNESS] == TRUE) thickness = cache.thickness;
-
 if (cache.new[STATIC_NET] == TRUE) projection = cache.projection;
 if (cache.new[STATIC_MODEL] == TRUE) type = cache.type;
 if (cache.new[STATIC_ORDER] == TRUE) order = cache.order;
@@ -1095,15 +1236,21 @@ if (cache.new[STATIC_SCALE] == TRUE) scale = cache.scale;
 
 if (cache.new[STATIC_REFERENCE] == TRUE)
   {
-  if (cache.reference == STATIC_ATOMS)
+  if (reference == GAMGI_ENGINE_ATOM)
     {
     cell = NULL;
     hkl[0] = 0; hkl[1] = 0; hkl[2] = 0;
     vectors = GAMGI_PHYS_PLANE_VECTORS;
-    type = GAMGI_PHYS_POLYGON;
     order = 1;
+    type = GAMGI_PHYS_POLYGON;
     projection = NULL;
     }
+
+  if (reference == GAMGI_ENGINE_CELL)
+    {
+    if (cell->type == GAMGI_PHYS_PROJECTION) order = 1;
+    else { type = GAMGI_PHYS_POLYGON; projection = NULL; }
+    }
   }
 
 /****************************
@@ -1121,7 +1268,7 @@ if (reference == GAMGI_ENGINE_CELL)
     }
 
   if ((type == GAMGI_PHYS_POLE || type == GAMGI_PHYS_TRACE) &&
-  (projection == NULL || cell == NULL || cell->type != GAMGI_PHYS_PROJECTION))
+  (projection == NULL || cell->type != GAMGI_PHYS_PROJECTION))
     {
     if (cache.local == TRUE)
       gamgi_gtk_dialog_message_create ("Error",
@@ -1147,9 +1294,10 @@ if (reference == GAMGI_ENGINE_CELL)
     {
     if (cache.local == TRUE)
       gamgi_gtk_dialog_message_create ("Error",
-      "Invalid plane parameters", window);
+      "Invalid direction parameters", window);
     return FALSE;
     }
+
   }
 
 if (reference == GAMGI_ENGINE_ATOM)
@@ -1186,7 +1334,6 @@ if (reference == GAMGI_ENGINE_ATOM)
     return FALSE;
     }
 
-
   if (type == GAMGI_PHYS_POLE || type == GAMGI_PHYS_TRACE ||
   type == GAMGI_PHYS_VECTOR)
     {
@@ -1220,14 +1367,13 @@ if (reference == GAMGI_ENGINE_ATOM)
       "Invalid plane parameters", window);
     return FALSE;
     }
-
   }
 
 /***************
  * handle node *
  ***************/
 
-if (cache.new[STATIC_NODES] == TRUE)
+if (cache.new[STATIC_NODES] > 0)
   {
   if (cell == NULL || gamgi_math_node_check (cell->lattice, cache.node[3]) == FALSE)
     {
@@ -1308,14 +1454,6 @@ if (cache.local == TRUE)
  * build new plane *
  *******************/
 
-/***************
- * reset plane *
- ***************/
-
-gamgi_math_vector_zero (zero);
-gamgi_math_position_plane_rotation_set (plane, zero);
-gamgi_math_position_plane_translation_set (plane, zero);
-
 strcpy (plane->object.name, name);
 plane->reference = reference;
 plane->hkl[0] = hkl[0];
@@ -1323,29 +1461,100 @@ plane->hkl[1] = hkl[1];
 plane->hkl[2] = hkl[2];
 plane->vectors = vectors;
 
+plane->order = order;
 plane->projection = projection;
 plane->type = type;
-plane->order = order;
 
 plane->red = red;
 plane->green = green;
 plane->blue = blue;
 plane->object.scale = scale;
 
-/*
 if (new == TRUE)
   {
+  /**************************************************************
+   * rebuild arrays: unlink plane AFTER removing contents, as   *
+   * reference atoms might need to be saved in the parent above *
+   **************************************************************/
+
+  static_plane_remove (plane, link);
+  gamgi_engine_unlink_plane (plane);
   free (plane->points);
-  free (plane->loops);
   plane->points = NULL;
+  free (plane->loops);
   plane->loops = NULL;
   plane->n_points = 0;
   plane->n_loops = 0;
-  }
-*/
 
-gamgi_math_position_plane_rotation_set (plane, euler);
-gamgi_math_position_plane_translation_set (plane, origin);
+  if (plane->reference == GAMGI_ENGINE_CELL)
+    {
+    /************************************
+     * this is a crystallographic plane *
+     ************************************/
+
+    if (cell->type == GAMGI_PHYS_PROJECTION)
+      {
+      if (plane->type == GAMGI_PHYS_POLE) pole = TRUE; else pole = FALSE;
+      if (plane->type == GAMGI_PHYS_TRACE) trace = TRUE; else trace = FALSE;
+      gamgi_phys_plane_projection (plane, cell, pole, trace);
+      }
+    else
+      {
+      dlist = gamgi_engine_dlist_atom_object (GAMGI_CAST_OBJECT cell, NULL);
+      dlist = gamgi_engine_filter_atom (dlist, 0, cache.filter,
+      GAMGI_ENGINE_PLANE, GAMGI_CAST_OBJECT cell);
+
+      gamgi_phys_plane_range (plane, cell, cache.structure,
+      cache.filter, cache.thickness, dlist, order, order);
+
+      while (dlist != NULL)
+        dlist = gamgi_engine_dlist_remove_start (dlist);
+      }
+    gamgi_engine_remove_plane (plane);
+    }
+
+  if (plane->reference == GAMGI_ENGINE_ATOM)
+    {
+    /**********************************************************
+     * this is an atomic plane: 1) get list of parent atoms   *
+     * 2) reorder list so the three defining atoms come first *
+     *                                                        *
+     * the plane type is needed because of the rotation next  *
+     **********************************************************/
+
+    plane->type = GAMGI_PHYS_POLYGON;
+    plane->vectors = GAMGI_PHYS_PLANE_VECTORS;
+
+    parent = gamgi_phys_plane_parent (cache.atom1, cache.atom2, cache.atom3, window);
+    dlist = gamgi_engine_dlist_atom_object (parent, NULL);
+    dlist = gamgi_phys_plane_reorder (dlist, cache.atom1, cache.atom2, cache.atom3);
+    dlist = gamgi_engine_filter_atom (dlist, 3, cache.filter, GAMGI_ENGINE_PLANE, parent);
+    if (parent->class <= GAMGI_ENGINE_PLANE) parent = GAMGI_CAST_OBJECT window->layer;
+
+    /*********************************************************
+     * reset and build plane polygon AFTER linking to parent *
+     *********************************************************/
+
+    gamgi_engine_link_object_object (GAMGI_CAST_OBJECT plane, parent);
+
+    gamgi_math_vector_zero (zero);
+    gamgi_math_position_plane_rotation_set (plane, zero);
+    gamgi_math_position_plane_translation_set (plane, zero);
+
+    gamgi_phys_plane_atoms (plane, cache.atom1, cache.atom2,
+    cache.atom3, dlist, cache.structure, cache.thickness);
+    static_atom_remove (plane, link);
+    }
+  }
+else
+  {
+  gamgi_math_vector_zero (zero);
+  gamgi_math_position_plane_rotation_set (plane, zero);
+  gamgi_math_position_plane_translation_set (plane, zero);
+
+  gamgi_math_position_plane_rotation_set (plane, euler);
+  gamgi_math_position_plane_translation_set (plane, origin);
+  }
 
 return TRUE;
 }
@@ -1543,14 +1752,13 @@ if (class == GAMGI_ENGINE_PLANE)
      ************************************/
 
     gtk_combo_box_set_active (GTK_COMBO_BOX (combo), STATIC_REFERENCE_CELL);
-    static_reference (NULL, window);
+    static_page_handle (window);
 
     /***************************
      * set cell identification *
      ***************************/
 
     cell = GAMGI_CAST_CELL plane->object.object;
-
     entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_cell");
     sprintf (string, "%s %d", cell->object.name, cell->object.number);
     gtk_entry_set_text (GTK_ENTRY (entry), string);
@@ -1614,7 +1822,7 @@ if (class == GAMGI_ENGINE_PLANE)
      ***************************/
 
     gtk_combo_box_set_active (GTK_COMBO_BOX (combo), STATIC_REFERENCE_ATOMS);
-    static_reference (NULL, window);
+    static_page_handle (window);
     }
 
   /***************************************
@@ -1686,10 +1894,11 @@ if (class == GAMGI_ENGINE_PLANE)
 
 else if (class == GAMGI_ENGINE_CELL)
   {
-  static_reference (NULL, window);
   entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_cell");
   sprintf (string, "%s %d", object->name, object->number);
   gtk_entry_set_text (GTK_ENTRY (entry), string);
+
+  static_page_hide (window);
   }
 else if (class == GAMGI_ENGINE_ATOM)
   {
@@ -1702,6 +1911,8 @@ else if (class == GAMGI_ENGINE_ATOM)
     { static_end_atom (dialog); entry = static_atom (dialog); }
   sprintf (string, "%s %d", object->name, object->number);
   gtk_entry_set_text (GTK_ENTRY (entry), string);
+
+  static_page_hide (window);
   }
 
 }
@@ -2219,7 +2430,7 @@ store = gtk_list_store_new (1, G_TYPE_STRING);
 gtk_list_store_append (store, &iter);
 gtk_list_store_set (store, &iter, 0, "Class", -1);
 gtk_list_store_append (store, &iter);
-gtk_list_store_set (store, &iter, 0, "Child", -1);
+gtk_list_store_set (store, &iter, 0, "Parent", -1);
 gtk_list_store_append (store, &iter);
 gtk_list_store_set (store, &iter, 0, "Identical", -1);
 gtk_list_store_append (store, &iter);
