@@ -24,6 +24,7 @@
 #include "gamgi_gtk_history.h"
 #include "gamgi_mesa_select.h"
 #include "gamgi_mesa_translate.h"
+#include "gamgi_mesa_draw.h"
 #include "gamgi_math_vector.h"
 #include "gamgi_io_token.h"
 #include "gamgi_io_error.h"
@@ -448,23 +449,6 @@ if (child->object == parent)
   return FALSE;
   }
 
-/*******************************************************************
- * some objects, such as planes and directions, might depend       *
- * entirely on their parents (crystallographic planes,directions), *
- * or have a life of their own (atomic planes,directions). Only    *
- * the second can be linked to other parents (not necessarily in   *
- * the same layer). Dependent objects can be linked, however,      *
- * to all possible child objects, without any restrictions.        *
- *******************************************************************/
-
-if (gamgi_gtk_object_independence (child) == FALSE)
-  {
-  if (cache.local == TRUE)
-    gamgi_gtk_dialog_message_create ("Error",
-    "Child is not an independent object", window);
-  return FALSE;
-  }
-
 /**********************************************
  * save layers before linking child to parent *
  **********************************************/
@@ -608,7 +592,7 @@ if (cache.above == FALSE)
 
 gamgi_io_error_list (start, window_dialog);
 
-gamgi_global_selection_draw ();
+gamgi_mesa_draw_gamgi ();
 
 /****************
  * reset dialog *
@@ -781,6 +765,7 @@ GdkEventButton *event, int x, int y, gamgi_window *window_dialog)
 GtkWidget *dialog = window_dialog->dialog0;
 GtkWidget *button;
 GtkWidget *entry;
+gamgi_bool global;
 const char *name;
 
 /***********************************************
@@ -796,13 +781,24 @@ if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == FALSE &&
 gamgi_io_token_check (name) == FALSE && 
 window_dialog != window_mouse) return;
 
+/***********************************************
+ * global selection can be used only to select *
+ * the second object, not the main object      *
+ ***********************************************/
+
+global = TRUE;
+if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == FALSE &&
+gamgi_io_token_check (name) == FALSE) global = FALSE;
+
 /************************************************************************
  * window_dialog is the (local) window where the dialog window was open *
  * window_mouse is the (global) window where the user presses the mouse *
  ************************************************************************/
 
+if (global == FALSE && window_dialog != window_mouse) return;
+
 gamgi_mesa_select_object (window_mouse, x, y,
-static_class (window_dialog), TRUE, static_press);
+static_class (window_dialog), global, static_press);
 }
 
 /***************** external function ***************
