@@ -101,8 +101,8 @@ GAMGI_IO_DEJAVU_MONO_ITALIC, GAMGI_IO_DEJAVU_MONO_BOLD_ITALIC };
  * the Gamgi->About GUI dialog *
  *******************************/
 
-#define GAMGI_IO_DATE "1st September 2011"
-#define GAMGI_IO_VERSION "0.15.5"
+#define GAMGI_IO_DATE "11th February 2012"
+#define GAMGI_IO_VERSION "0.15.6"
 #define GAMGI_IO_AUTHORS "Carlos Pereira et al."
 #define GAMGI_IO_LICENSE "GPL"
 #define GAMGI_IO_WEBSITE "http://www.gamgi.org/"
