@@ -269,6 +269,7 @@ gamgi_direction *direction, double new, double *translate,
 gamgi_layer *layer)
 {
 gamgi_cell *cell;
+gamgi_object *object;
 double pole[3], normal[3];
 double r1[3], r2[3];
 double old;
@@ -308,8 +309,9 @@ else
    * passing through the cell origin    *
    **************************************/
 
-  if (direction->reference != GAMGI_ENGINE_CELL) return FALSE;
-  cell = GAMGI_CAST_CELL direction->object.object;
+  object = GAMGI_CAST_OBJECT direction->object.object;
+  if (object->class != GAMGI_ENGINE_CELL) return FALSE;
+  cell = GAMGI_CAST_CELL object;
 
   gamgi_phys_direction_vector (cell, direction->uvw, direction->vectors, pole);
   gamgi_math_cell_vector_rotate (cell, pole, normal);
@@ -336,6 +338,7 @@ gamgi_bool gamgi_math_modify_get_length_atom_plane (gamgi_atom *atom,
 gamgi_plane *plane, double new, double *translate, gamgi_layer *layer)
 {
 gamgi_cell *cell;
+gamgi_object *object;
 double pole[3], normal[3];
 double origin[3];
 double r1[3];
@@ -373,19 +376,21 @@ else
    * or projection): the parent must be a cell   *
    ***********************************************/
 
-  if (plane->reference != GAMGI_ENGINE_CELL) return FALSE;
-  cell = GAMGI_CAST_CELL plane->object.object;
+  object = GAMGI_CAST_OBJECT plane->object.object;
+  if (object->class != GAMGI_ENGINE_CELL) return FALSE;
+  cell = GAMGI_CAST_CELL object;
 
   /********************
    * reciprocal space *
    ********************/
 
-  if (plane->reciprocal != 0)
+  if (plane->type == GAMGI_PHYS_VECTOR)
     {
     /********************
      * reciprocal space *
      ********************/
 
+    if (cell->reciprocal == 0.0) return FALSE;
     gamgi_phys_plane_point (plane, cell, r1);
     gamgi_math_vector_sub (atom->position, r1, translate);
     old = gamgi_math_vector_length (translate);
