@@ -246,13 +246,17 @@ GAMGI_MESA_SELECT_RESIZE };
 #define GAMGI_MESA_GROUP_G 1.0
 #define GAMGI_MESA_GROUP_B 1.0
 
-/*************************************************
- * width used to render Plane, Direction objects *
- * as cross, chess bitmap masks in Stereographic *
- * Projection and Reciprocal Lattice             *
- *************************************************/
+/*********************************************************
+ * POLE: default width used to render Plane, Direction   *
+ * objects as cross, chess bitmap masks in Stereographic *
+ * Projection and Reciprocal Lattice                     *
+ *                                                       *
+ * TRACE: default width used to render Plane, Direction  *
+ * objects as arcs in Stereographic Projection           *
+ *********************************************************/
 
-#define GAMGI_MESA_PLANE_WIDTH 3
+#define GAMGI_MESA_POLE_WIDTH  3
+#define GAMGI_MESA_TRACE_WIDTH 1
 
 /****************************************
  * number of slices used to draw plane  *
