@@ -37,12 +37,14 @@
 #include "gamgi_gtk_atom_measure.h"
 #include "gamgi_gtk_atom_remove.h"
 #include "gamgi_gtk_direction_create.h"
+#include "gamgi_gtk_direction_copy.h"
 #include "gamgi_gtk_direction_select.h"
 #include "gamgi_gtk_direction_link.h"
 #include "gamgi_gtk_direction_modify.h"
 #include "gamgi_gtk_direction_measure.h"
 #include "gamgi_gtk_direction_remove.h"
 #include "gamgi_gtk_plane_create.h"
+#include "gamgi_gtk_plane_copy.h"
 #include "gamgi_gtk_plane_select.h"
 #include "gamgi_gtk_plane_link.h"
 #include "gamgi_gtk_plane_modify.h"
@@ -677,6 +679,10 @@ switch (window_dialog->action)
   gamgi_gtk_direction_create_press (window_mouse, event, x, y, window_dialog);
   return TRUE;
 
+  case GAMGI_GTK_DIRECTION_COPY:
+  gamgi_gtk_direction_copy_press (window_mouse, event, x, y, window_dialog);
+  return TRUE;
+
   case GAMGI_GTK_DIRECTION_SELECT:
   gamgi_gtk_direction_select_press (window_mouse, event, x, y, window_dialog);
   return TRUE;
@@ -701,6 +707,10 @@ switch (window_dialog->action)
   gamgi_gtk_plane_create_press (window_mouse, event, x, y, window_dialog);
   return TRUE;
 
+  case GAMGI_GTK_PLANE_COPY:
+  gamgi_gtk_plane_copy_press (window_mouse, event, x, y, window_dialog);
+  return TRUE;
+
   case GAMGI_GTK_PLANE_SELECT:
   gamgi_gtk_plane_select_press (window_mouse, event, x, y, window_dialog);
   return TRUE;
